@@ -24,7 +24,7 @@ import json
 from gi.repository import Gtk
 from gi.repository import GLib
 
-from gtweak.utils import walk_directories, extract_zip_file
+from gtweak.utils import walk_directories, extract_zip_file, make_combo_list_with_default
 from gtweak.gsettings import GSettingsSetting
 from gtweak.gshellwrapper import GnomeShell
 from gtweak.tweakmodel import Tweak, TweakGroup
@@ -52,11 +52,11 @@ class ShellThemeTweak(Tweak):
         Tweak.__init__(self, "Shell Theme", "Install custom or user themes for gnome-shell", **options)
 
         #check the shell is running and the usertheme extension is present
-        error = "Unknown"
+        error = _("Unknown error")
         try:
             self._shell = GnomeShell()
         except:
-            error = "Shell not running"
+            error = _("Shell not running")
         try:
             extensions = self._shell.list_extensions()
             if ShellThemeTweak.THEME_EXT_NAME in extensions and extensions[ShellThemeTweak.THEME_EXT_NAME]["state"] == 1:
@@ -68,25 +68,22 @@ class ShellThemeTweak(Tweak):
                     #assume the usertheme version is that version of the shell which
                     #it most supports (this is a poor assumption)
                     self._usertheme_extension_version = max(extensions[ShellThemeTweak.THEME_EXT_NAME]["shell-version"])
+                    logging.debug("Shell user-theme extension v%s", self._usertheme_extension_version)
 
                     error = None
                 except:
-                    error = "User Theme extension schema missing"
+                    error = _("Shell user-theme extension incorrectly installed")
 
             else:
-                error = "User Theme extension not enabled"
+                error = _("Shell user-theme extension not enabled")
         except Exception, e:
-            error = "Could not list shell extensions"
+            error = _("Could not list shell extensions")
 
         if error:
-            info = Gtk.InfoBar()
-            info.props.message_type = Gtk.MessageType.INFO
-            info.get_content_area().add(Gtk.Label(error))
-            self.widget = build_label_beside_widget(self.name, info)
-            self.widget_for_size_group = info
+            cb = build_combo_box_text(None)
+            self.widget = build_label_beside_widget(self.name, cb, warning=error)
+            self.widget_for_size_group = cb
         else:
-            hb = Gtk.HBox()
-
             #include both system, and user themes
             #note: the default theme lives in /system/data/dir/gnome-shell/theme
             #      and not themes/, so add it manually later
@@ -96,22 +93,25 @@ class ShellThemeTweak(Tweak):
             valid = walk_directories(dirs, lambda d:
                         os.path.exists(os.path.join(d, "gnome-shell")) and \
                         os.path.exists(os.path.join(d, "gnome-shell", "gnome-shell.css")))
-
-            chooser = ZipFileChooserButton("Select a theme file")
-            chooser.connect("file-set", self._on_file_set)
-            hb.pack_start(chooser, False, False, 5)
+            #the default value to reset the shell is an empty string
+            valid.extend( ("",) )
 
             #build a combo box with all the valid theme options
             #manually add Adwaita to represent the default
             cb = build_combo_box_text(
                     self._settings.get_string(ShellThemeTweak.THEME_GSETTINGS_NAME),
-                    ("", "default"),
-                    *[(v,v) for v in valid])
+                    *make_combo_list_with_default(
+                        valid,
+                        "",
+                        default_text=_("<i>Default</i>")))
             cb.connect('changed', self._on_combo_changed)
-            hb.pack_start(cb, False, False, 0)
-            self.combo = cb
+            self._combo = cb
 
-            self.widget = build_label_beside_widget(self.name, hb)
+            #a filechooser to install new themes
+            chooser = ZipFileChooserButton(_("Select a theme"))
+            chooser.connect("file-set", self._on_file_set)
+
+            self.widget = build_label_beside_widget(self.name, chooser, cb)
             self.widget_for_size_group = cb
     
     def _on_file_set(self, chooser):
@@ -139,7 +139,7 @@ class ShellThemeTweak(Tweak):
                     raise Exception("Could not find gnome-shell.css")
 
                 if not theme_name:
-                    logging.info("Old style theme detected (theme.json)")
+                    logging.info("Old style theme detected (missing theme.json)")
                     #old style themes name was taken from the zip name
                     if fragment[0] == "theme" and len(fragment) == 1:
                         theme_name = os.path.basename(f)
@@ -155,22 +155,22 @@ class ShellThemeTweak(Tweak):
 
                 if ok:
                     if updated:
-                        self.notify_info("%s theme updated successfully" % theme_name)
+                        self.notify_info(_("%s theme updated successfully") % theme_name)
                     else:
-                        self.notify_info("%s theme installed successfully" % theme_name)
+                        self.notify_info(_("%s theme installed successfully") % theme_name)
 
                     #I suppose I could rely on updated as indicating whether to add the theme
                     #name to the combo, but just check to see if it is already there
-                    model = self.combo.get_model()
+                    model = self._combo.get_model()
                     if theme_name not in [r[0] for r in model]:
                         model.append( (theme_name, theme_name) )
                 else:
-                    self.notify_error("Error installing theme")
+                    self.notify_error(_("Error installing theme"))
 
 
             except:
                 #does not look like a valid theme
-                self.notify_error("Invalid theme file")
+                self.notify_error(_("Invalid theme"))
                 logging.warning("Error parsing theme zip", exc_info=True)
 
         #set button back to default state
@@ -191,16 +191,17 @@ class ShellThemeTweak(Tweak):
         if not val:
             if self._usertheme_extension_version < "3.0.2":
                 self.notify_action_required(
-                    "The shell must be restarted to apply the theme",
-                    "Restart",
+                    _("The shell may need to be restarted to apply the theme"),
+                    _("Restart"),
                     lambda: self._shell.restart())
 
 sg = build_horizontal_sizegroup()
 
 TWEAK_GROUPS = (
         TweakGroup(
-            "Shell",
+            _("Shell"),
             GSettingsSwitchTweak("org.gnome.shell.clock", "show-date", schema_filename="org.gnome.shell.gschema.xml"),
+            GSettingsSwitchTweak("org.gnome.shell.clock", "show-seconds", schema_filename="org.gnome.shell.gschema.xml"),
             GSettingsSwitchTweak("org.gnome.shell.calendar", "show-weekdate", schema_filename="org.gnome.shell.gschema.xml"),
             ShowWindowButtons(size_group=sg),
             ShellThemeTweak(size_group=sg),
